@@ -8,6 +8,7 @@
 #define DEFAULT_Accelerometer false
 #define DEFAULT_Autopause false
 #define DEFAULT_Scale 2
+#define DEFAULT_Filter 0
 #define DEFAULT_FrameskipType 1
 #define DEFAULT_FrameskipValue 1
 #define DEFAULT_FrameskipRandom false
@@ -22,9 +23,10 @@ public:
     bool accelerometer;   // --accelerometer
     bool autopause;       // --autopause
     int  scale;           // --scale N
+    int  filter;          // --filter N
     int  frameskipType;   // --frameskip-type N
     int  frameskipValue;  // --frameskip-value N
-    bool frameskipRandom;  // --random-frameskip
+    bool frameskipRandom; // --random-frameskip
     bool soundDisabled;   // --no-sound
     int  soundBuffer;     // --sound-buffer N
     QString executeBefore;
